@@ -1,6 +1,5 @@
 from logging import NullHandler, getLogger
 
-import babelfish
 from trakit.api import trakit
 
 from knowit.core import Rule
@@ -15,7 +14,9 @@ class GuessTitleRule(Rule):
     def execute(self, props, pv_props, context):
         """Language detection using name."""
         if 'name' in props:
-            guessed = trakit(props['name'])
+            language = props.get('language')
+            options = {'expected_language': language} if language else {}
+            guessed = trakit(props['name'], options)
             if guessed:
                 return guessed
 
@@ -30,13 +31,4 @@ class LanguageRule(Rule):
 
         guess = pv_props['guessed']
         if 'language' in guess:
-            guessed: babelfish.Language = guess['language']
-            if 'language' not in props:
-                return guessed
-
-            lang: babelfish.Language = props['language']
-            if guessed.alpha3 != lang.alpha3 or str(lang).count('-') >= str(guessed).count('-'):
-                logger.debug('Discarding %s: Language %r and guessed %r', self.description, lang, guessed)
-                return lang
-
-            return guessed
+            return guess['language']
