@@ -1,5 +1,8 @@
+import logging
 import typing
 
+logger = logging.getLogger(__name__)
+
 
 class NullRegistry:
     """A NullRegistry that masquerades as a pint.UnitRegistry."""
@@ -11,6 +14,17 @@ class NullRegistry:
         """Return a Scalar 1 to simulate a unit."""
         return 1
 
+    def __call__(self, value: str) -> float:
+        """Try converting to int, to float and fallback to a scalar 1.0."""
+        try:
+            return int(value)
+        except ValueError:
+            try:
+                return float(value)
+            except ValueError:
+                pass
+        return 1
+
     def __bool__(self):
         """Return False since a NullRegistry is not a pint.UnitRegistry."""
         return False
@@ -25,9 +39,13 @@ def _build_unit_registry():
 
         registry = pint.UnitRegistry()
         registry.define('FPS = 1 * hertz')
+
+        pint.set_application_registry(registry)
         return registry
     except ModuleNotFoundError:
         pass
+    except Exception:
+        logger.exception("Cannot import the pint package")
 
     return NullRegistry()
 
